[][src]Struct math2d::Rectu

#[repr(C)]
pub struct Rectu { pub left: u32, pub top: u32, pub right: u32, pub bottom: u32, }

Represents a rectangle defined by the coordinates of the upper-left corner (left, top) and the coordinates of the lower-right corner (right, bottom).

Fields

left: u32

The x-coordinate of the upper-left corner of the rectangle.

top: u32

The y-coordinate of the upper-left corner of the rectangle.

right: u32

The x-coordinate of the lower-right corner of the rectangle.

bottom: u32

The y-coordinate of the lower-right corner of the rectangle.

Methods

impl Rectu[src]

pub fn new(left: u32, top: u32, right: u32, bottom: u32) -> Rectu[src]

Constructs the rectangle from components.

pub fn to_f32(&self) -> Rectf[src]

Converts the rectangle to floating point values.

pub fn to_i32(&self) -> Recti[src]

Converts the rectangle to signed integer values. Beware of casting overflow if any of the components are greater than i32::MAX.