[−][src]Struct math2d::RoundedRect
Represents a rectangle with rounded corners described by ellipses that touch the internal edges of the rectangle at the tangent points.

Fields
rect: RectfThe overall rectangle containing this rounded rectangle
radius_x: f32The x-radius of the ellipse nested in each corner.
radius_y: f32The y-radius of the ellipse nested in each corner.
Methods
impl RoundedRect[src]
pub fn new(rect: impl Into<Rectf>, rx: f32, ry: f32) -> RoundedRect[src]
Constructs the rounded rectangle from its components
pub fn corner_ellipse(&self, corner: RectCorner) -> Ellipse[src]
Gets the ellipse that resides in the given corner of the rectangle
pub fn contains_point(&self, point: impl Into<Point2f>) -> bool[src]
Checks if the given point resides within the rounded rectangle, taking care to exclude the parts of the corners that are excluded from the ellipses.
pub fn contains_point_crude(&self, point: impl Into<Point2f>) -> bool[src]
Checks if the point resides within the rectangle without checking the
corner cases of being inside the square rectangle but not inside the
rounded corners. This function may be decently faster than
contains_point.