[−][src]Struct math2d::Vector2f
Mathematical vector on the 2D (x, y) plane.
Fields
x: f32Horizontal component.
y: f32Vertical component.
Methods
impl Vector2f[src]
pub const ZERO: Vector2f[src]
Zero vector, addition identity value.
pub const ONE: Vector2f[src]
One vector, multiplication identity value.
pub const UP: Vector2f[src]
Up vector in the top-left coordinate system common to 2D drawing systems.
pub const RIGHT: Vector2f[src]
Right vector in the top-left coordinate system common to 2D drawing systems.
pub const DOWN: Vector2f[src]
Down vector in the top-left coordinate system common to 2D drawing systems.
pub const LEFT: Vector2f[src]
Left vector in the top-left coordinate system common to 2D drawing systems.
pub fn new(x: f32, y: f32) -> Self[src]
Construct a vector from the components.
pub fn to_i32(self) -> Vector2i[src]
Converts the vector to unsigned integer values. Truncates integers, if you want your components to be rounded you must do this manually first.
pub fn to_point(self) -> Point2f[src]
pub fn to_size(self) -> Sizef[src]
Converts this vector to a size value with the x representing width and the y representing height.
pub fn rounded(self) -> Vector2f[src]
Rounds the components of the vector to the nearest integer. Rounds half-way values away from 0.
pub fn dot(self, rhs: Vector2f) -> f32[src]
Dot product of two vectors.
pub fn len_squared(self) -> f32[src]
The squared length of the vector
pub fn len(self) -> f32[src]
The length of the vector. This requires performing a square root, so the squared length should be preferred where possible.
pub fn abs(self) -> Self[src]
Absolute value of the vector components.
pub fn reciprocal(self) -> Self[src]
Component-wise reciprocal
pub fn is_approx_eq(self, other: impl Into<Vector2f>, epsilon: f32) -> bool[src]
Tests if two vectors are approximately equal to each other within a given epsilon. The epsilon is applied component-wise. If you would like to check that two vectors are within a specified distance of each other, you should subtract one from the other and check the length of the resulting distance vector between them.